==> nextcloud-12.0.11.tar.bz2: nextcloud/apps/firstrunwizard/l10n/en_GB.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "First run wizard",
    "Add your profile information! For example your email is needed to reset your password." : "Add your profile information! For example your email is needed to reset your password.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Add your profile information! Set a profile picture and full name for easier recognition across all features.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Add your profile information! Set a full name for easier recognition across all features.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Add your profile information! Set a profile picture for easier recognition across all features.",
    "About" : "About",
    "A welcome and introduction wizard for Nextcloud" : "A welcome and introduction wizard for Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard button can be opened again via the link on the personal page.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the First run wizard documentation, as well as the theming documentation." : "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard button can be opened again via the link on the personal page.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the First run wizard documentation, as well as the theming documentation.",
    "Extend your cloud" : "Extend your cloud",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Find more than 100 apps in the Nextcloud app store to customise your cloud:",
    "Groupware apps like Calendar, Contacts, Mail" : "Groupware apps like Calendar, Contacts, Mail",
    "Communication with Nextcloud Talk" : "Communication with Nextcloud Talk",
    "Collaboration apps for document editing" : "Collaboration apps for document editing",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Security and authentication features like two-factor authentication, SSO and ransomware protection",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor",
    "Browse the app store" : "Browse the app store",
    "Stay in sync" : "Stay in sync",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud gives you access to your files wherever you are.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!",
    "Get the apps to sync your files" : "Get the apps to sync your files",
    "Desktop client" : "Desktop client",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Connect your desktop apps to %s" : "Connect your desktop apps to %s",
    "Connect your calendar" : "Connect your calendar",
    "Connect your contacts" : "Connect your contacts",
    "Access files via WebDAV" : "Access files via WebDAV",
    "Get help" : "Get help",
    "Get more information" : "Get more information",
    "The Nextcloud documentation for home users:" : "The Nextcloud documentation for home users:",
    "User manual" : "User manual",
    "Admin manual" : "Admin manual",
    "Developer manual" : "Developer manual",
    "You can also ask for help in our community support channels:" : "You can also ask for help in our community support channels:",
    "the Nextcloud forums" : "the Nextcloud forums",
    "the Nextcloud IRC chat channel on freenode.net" : "the Nextcloud IRC chat channel on freenode.net",
    "Start contributing" : "Start contributing",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?",
    "Become part of the Community" : "Become part of the Community",
    "Enterprise support" : "Enterprise support",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support.",
    "Get enterprise support" : "Get enterprise support",
    "A safe home for all your data" : "A safe home for all your data",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know.",
    "Host your data and files where you decide" : "Host your data and files where you decide",
    "Open Standards and Interoperability" : "Open Standards and Interoperability",
    "100%% Open Source & community-focused" : "100%% Open Source & community-focused",
    "Learn more about %s" : "Learn more about %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost.",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device.",
    "Connect other apps to %s" : "Connect other apps to %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s.",
    "Previous" : "Previous",
    "Next" : "Next",
    "Start using Nextcloud" : "Start using Nextcloud",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Access & share your files, calendars, contacts, mail & more from any device, on your terms",
    "Connect your Calendar" : "Connect your Calendar",
    "Connect your Contacts" : "Connect your Contacts",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!",
    "Show First Run Wizard again" : "Show First Run Wizard again"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2.tar.bz2: nextcloud/apps/firstrunwizard/l10n/en_GB.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "First run wizard",
    "Add your profile information! For example your email is needed to reset your password." : "Add your profile information! For example your email is needed to reset your password.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Add your profile information! Set a profile picture and full name for easier recognition across all features.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Add your profile information! Set a full name for easier recognition across all features.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Add your profile information! Set a profile picture for easier recognition across all features.",
    "Get the apps to sync your files" : "Get the apps to sync your files",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost.",
    "Desktop client" : "Desktop client",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Setup sync clients using an <a href=\"\">app password</a>. That way you can make sure you are able to revoke access in case you loose that device." : "Setup sync clients using an <a href=\"\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device.",
    "Connect other apps to %s" : "Connect other apps to %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s.",
    "Connect your calendar" : "Connect your calendar",
    "Connect your contacts" : "Connect your contacts",
    "Access files via WebDAV" : "Access files via WebDAV",
    "The first run wizard helps you to get started with %s." : "The first run wizard helps you to get started with %s.",
    "Show first run wizard again" : "Show first run wizard again",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Access & share your files, calendars, contacts, mail & more from any device, on your terms",
    "Connect your desktop apps to %s" : "Connect your desktop apps to %s",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!",
    "Connect your Calendar" : "Connect your Calendar",
    "Connect your Contacts" : "Connect your Contacts",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!",
    "Show First Run Wizard again" : "Show First Run Wizard again"
},
"nplurals=2; plural=(n != 1);");
